@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
+ * Copyright (C) 2007-2022  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As an exception, when this program is distributed through (i) the App Store
  * by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or (iii) Google Play
@@ -54,14 +54,9 @@
 
 #include "libnormaliz/my_omp.h"
 
-
-#ifdef _WIN32     // for 32 and 64 bit windows
-#define NMZ_MPIR  // always use MPIR
-#endif
-
-#ifdef NMZ_MPIR  // use MPIR
+#ifdef USE_MPIR
 #include <mpirxx.h>
-#else  // otherwise use GMP 
+#else  // otherwise use GMP
 #include <gmpxx.h>
 #endif
 
@@ -73,16 +68,16 @@
 #ifdef ENFNORMALIZ
 #include <e-antic/renfxx.h>
 namespace libnormaliz {
-using eantic::renf_elem_class;
 using eantic::renf_class;
+using eantic::renf_elem_class;
 typedef boost::intrusive_ptr<const renf_class> renf_class_shared;
-}
+}  // namespace libnormaliz
 #else
 namespace libnormaliz {
 typedef long renf_elem_class;
-struct renf_class{};
+struct renf_class {};
 typedef renf_class* renf_class_shared;
-}
+}  // namespace libnormaliz
 #endif
 
 namespace libnormaliz {
@@ -134,6 +129,10 @@ NORMALIZ_DLL_EXPORT extern long thread_limit;
 NORMALIZ_DLL_EXPORT extern bool parallelization_set;
 long set_thread_limit(long t);
 
+// debugging helpers
+NORMALIZ_DLL_EXPORT extern long cone_recursion_level;
+NORMALIZ_DLL_EXPORT extern long full_cone_recursion_level;
+
 /* set the verbose default value */
 bool setVerboseDefault(bool v);
 /* methods to set and use the output streams */
